pub struct WorkItem {
pub step: String,
pub done: bool,
pub evidence: Option<String>,
}Fields
step: Stringdone: boolMust be true before the loop is allowed to run. This encodes the corpus rule that you cannot automate a process you cannot describe.
evidence: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for WorkItem
impl<'de> Deserialize<'de> for WorkItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkItem
impl JsonSchema for WorkItem
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkItem
impl RefUnwindSafe for WorkItem
impl Send for WorkItem
impl Sync for WorkItem
impl Unpin for WorkItem
impl UnsafeUnpin for WorkItem
impl UnwindSafe for WorkItem