pub struct WorkItem {
pub step: String,
pub done: bool,
pub evidence: Option<String>,
}Fields
step: Stringdone: boolMust be true before the loop is allowed to run. This encodes the corpus rule that you cannot automate a process you cannot describe.
evidence: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for WorkItem
impl<'de> Deserialize<'de> for WorkItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more